Struct TransferBlocked
pub struct TransferBlocked {
pub token: Address,
pub receiver: Address,
pub blockedNonce: u64,
pub amount: Uint<256, 4>,
pub receiptVersion: u8,
pub receipt: Bytes,
}Expand description
@notice Emitted when an inbound TIP-20 transfer or mint is blocked and funds are redirected.
@param token TIP-20 token whose funds are held by the guard.
@param receiver Resolved account where funds would settle; for virtual recipients its their master.
@param blockedNonce Guard nonce assigned to the blocked operation.
@param amount Amount of blocked funds held by the guard.
@param receiptVersion Claim receipt layout version.
@param receipt ABI-encoded receipt witness that can be passed to claim.
Event with signature TransferBlocked(address,address,uint64,uint256,uint8,bytes) and selector 0x361d86e46fd139dc3eac4148f16b53597f0f8ddd9aba772aae0034bda5531b1c.
event TransferBlocked(address indexed token, address indexed receiver, uint64 indexed blockedNonce, uint256 amount, uint8 receiptVersion, bytes receipt);Fields
token: Addressreceiver: AddressblockedNonce: u64amount: Uint<256, 4>receiptVersion: u8receipt: BytesTrait Implementations
impl Clone for TransferBlocked
impl Clone for TransferBlocked
fn clone(&self) -> TransferBlocked
fn clone(&self) -> TransferBlocked
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreimpl Debug for TransferBlocked
impl Debug for TransferBlocked
impl<'de> Deserialize<'de> for TransferBlocked
impl<'de> Deserialize<'de> for TransferBlocked
fn deserialize<__D>(
__deserializer: __D,
) -> Result<TransferBlocked, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<TransferBlocked, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
impl Eq for TransferBlocked
impl IntoLogData for TransferBlocked
impl IntoLogData for TransferBlocked
fn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
LogData] object.fn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
LogData] object.impl JsonAbiExt for TransferBlocked
impl JsonAbiExt for TransferBlocked
fn abi() -> <TransferBlocked as JsonAbiExt>::Abi
fn abi() -> <TransferBlocked as JsonAbiExt>::Abi
impl PartialEq for TransferBlocked
impl PartialEq for TransferBlocked
impl Serialize for TransferBlocked
impl Serialize for TransferBlocked
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
impl SolEvent for TransferBlocked
impl SolEvent for TransferBlocked
const SIGNATURE: &'static str = "TransferBlocked(address,address,uint64,uint256,uint8,bytes)"
const SIGNATURE: &'static str = "TransferBlocked(address,address,uint64,uint256,uint8,bytes)"
const SIGNATURE_HASH: FixedBytes<32>
const SIGNATURE_HASH: FixedBytes<32>
keccak256(SIGNATURE) Read moretype DataTuple<'a> = (Uint<256>, Uint<8>, Bytes)
type DataTuple<'a> = (Uint<256>, Uint<8>, Bytes)
type DataToken<'a> = <<TransferBlocked as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
type DataToken<'a> = <<TransferBlocked as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
TokenSeq] type corresponding to the tuple.type TopicList = (FixedBytes<32>, Address, Address, Uint<64>)
type TopicList = (FixedBytes<32>, Address, Address, Uint<64>)
fn new(
topics: <<TransferBlocked as SolEvent>::TopicList as SolType>::RustType,
data: <<TransferBlocked as SolEvent>::DataTuple<'_> as SolType>::RustType,
) -> TransferBlocked
fn new( topics: <<TransferBlocked as SolEvent>::TopicList as SolType>::RustType, data: <<TransferBlocked as SolEvent>::DataTuple<'_> as SolType>::RustType, ) -> TransferBlocked
fn check_signature(
topics: &<<TransferBlocked as SolEvent>::TopicList as SolType>::RustType,
) -> Result<(), Error>
fn check_signature( topics: &<<TransferBlocked as SolEvent>::TopicList as SolType>::RustType, ) -> Result<(), Error>
fn tokenize_body(&self) -> <TransferBlocked as SolEvent>::DataToken<'_>
fn tokenize_body(&self) -> <TransferBlocked as SolEvent>::DataToken<'_>
fn topics(
&self,
) -> <<TransferBlocked as SolEvent>::TopicList as SolType>::RustType
fn topics( &self, ) -> <<TransferBlocked as SolEvent>::TopicList as SolType>::RustType
fn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<(), Error>
fn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<(), Error>
fn new_checked(
topics: <Self::TopicList as SolType>::RustType,
data: <Self::DataTuple<'_> as SolType>::RustType,
) -> Result<Self, Error>
fn new_checked( topics: <Self::TopicList as SolType>::RustType, data: <Self::DataTuple<'_> as SolType>::RustType, ) -> Result<Self, Error>
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
fn encode_data_to(&self, out: &mut Vec<u8>)
fn encode_data_to(&self, out: &mut Vec<u8>)
fn encode_data(&self) -> Vec<u8> ⓘ
fn encode_data(&self) -> Vec<u8> ⓘ
fn encode_topics(&self) -> Vec<WordToken>
fn encode_topics(&self) -> Vec<WordToken>
fn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
fn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
fn encode_log_data(&self) -> LogData
fn encode_log_data(&self) -> LogData
LogData].fn encode_log(log: &Log<Self>) -> Log
fn encode_log(log: &Log<Self>) -> Log
Log] containing this event into a [Log] containing
[LogData].fn decode_topics<I, D>(
topics: I,
) -> Result<<Self::TopicList as SolType>::RustType, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn decode_topics<I, D>(
topics: I,
) -> Result<<Self::TopicList as SolType>::RustType, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn abi_decode_data<'a>(
data: &'a [u8],
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data<'a>( data: &'a [u8], ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data_validate<'a>(
data: &'a [u8],
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data_validate<'a>( data: &'a [u8], ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn decode_raw_log<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn decode_raw_log<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn decode_raw_log_validate<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn decode_raw_log_validate<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn decode_log_data(log: &LogData) -> Result<Self, Error>
fn decode_log_data(log: &LogData) -> Result<Self, Error>
fn decode_log_data_validate(log: &LogData) -> Result<Self, Error>
fn decode_log_data_validate(log: &LogData) -> Result<Self, Error>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
fn decode_log_validate(log: &Log) -> Result<Log<Self>, Error>
fn decode_log_validate(log: &Log) -> Result<Log<Self>, Error>
impl StructuralPartialEq for TransferBlocked